#[test]
fn ui_tests() {
    let t = trybuild::TestCases::new();
    t.pass("tests/ui/route_get.rs");
    t.compile_fail("tests/ui/empty_path.rs");
    t.compile_fail("tests/ui/glob.rs");
}
